summaryrefslogtreecommitdiffstats
path: root/src/declarative/qml/rewriter/textwriter_p.h
diff options
context:
space:
mode:
authorWarwick Allison <warwick.allison@nokia.com>2010-02-24 02:42:00 (GMT)
committerWarwick Allison <warwick.allison@nokia.com>2010-02-24 02:42:00 (GMT)
commit7c76abb0dc4204043bec9b6fa315f9753a7986ae (patch)
treecee303672cfd138790645e731f2d69472564d4b7 /src/declarative/qml/rewriter/textwriter_p.h
parent4066e60e859853cfe3240245ba05271e79839506 (diff)
downloadQt-7c76abb0dc4204043bec9b6fa315f9753a7986ae.zip
Qt-7c76abb0dc4204043bec9b6fa315f9753a7986ae.tar.gz
Qt-7c76abb0dc4204043bec9b6fa315f9753a7986ae.tar.bz2
Change class prefix to from QmlXXX to QDeclarativeXXX, QmlGraphicsXXX to QDeclarativeXXX.
Diffstat (limited to 'src/declarative/qml/rewriter/textwriter_p.h')
-rw-r--r--src/declarative/qml/rewriter/textwriter_p.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/declarative/qml/rewriter/textwriter_p.h b/src/declarative/qml/rewriter/textwriter_p.h
index 43ef669..c712626 100644
--- a/src/declarative/qml/rewriter/textwriter_p.h
+++ b/src/declarative/qml/rewriter/textwriter_p.h
@@ -42,7 +42,7 @@
#ifndef TEXTWRITER_H
#define TEXTWRITER_H
-#include <qmljsglobal_p.h>
+#include <qdeclarativejsglobal_p.h>
#include <QtCore/QString>
#include <QtCore/QList>
@@ -51,7 +51,7 @@
QT_BEGIN_HEADER
QT_QML_BEGIN_NAMESPACE
-namespace QmlJS {
+namespace QDeclarativeJS {
class TextWriter
{
@@ -93,7 +93,7 @@ public:
};
-} // end of namespace QmlJS
+} // end of namespace QDeclarativeJS
QT_QML_END_NAMESPACE
QT_END_HEADER